Rc

Struct Rc 

pub struct Rc { /* private fields */ }

Implementations

Source

impl Rc

pub fn new() -> Self

Creates a new, uninitialized RC handler

pub fn init(&mut self, params: &Params)

Initializes RC internal mappings from parameters.

pub fn param_change_callback(&mut self, param_id: ParamId, params: &Params)

pub fn receive(&mut self, packet: &RcPacket)

pub fn check_rc_health(&self, now_us: u64, params: &Params) -> bool

pub fn run( &mut self, now_ms: u32, params: &Params, state_manager: &mut StateManager, )

pub fn new_command(&mut self) -> bool

Returns true if a new command has been processed

pub fn stick(&self, channel: Stick) -> f32

Gets the processed stick value (-1.0 to 1.0, or 0.0 to 1.0 for F)

pub fn switch_on(&self, channel: Switch) -> bool

Gets the processed switch value (true or false)

pub fn switch_mapped(&self, channel: Switch) -> bool

Checks if a switch is mapped to a channel

pub fn get_rc_struct(&self) -> &RcStruct

Gets a reference to the raw, unprocessed RC data

pub fn read_raw_chan(&self, chan_idx: usize) -> f32

Reads a raw, normalized (0.0 to 1.0) channel value