pub struct Rc { /* private fields */ }Implementations
Sourceimpl Rc
impl Rc
pub fn param_change_callback(&mut self, param_id: ParamId, params: &Params)
pub fn receive(&mut self, packet: &RcPacket)
pub fn check_rc_health(&self, now_us: u64, params: &Params) -> bool
pub fn run( &mut self, now_ms: u32, params: &Params, state_manager: &mut StateManager, )
Sourcepub fn new_command(&mut self) -> bool
pub fn new_command(&mut self) -> bool
Returns true if a new command has been processed
Sourcepub fn stick(&self, channel: Stick) -> f32
pub fn stick(&self, channel: Stick) -> f32
Gets the processed stick value (-1.0 to 1.0, or 0.0 to 1.0 for F)
Sourcepub fn switch_on(&self, channel: Switch) -> bool
pub fn switch_on(&self, channel: Switch) -> bool
Gets the processed switch value (true or false)
Sourcepub fn switch_mapped(&self, channel: Switch) -> bool
pub fn switch_mapped(&self, channel: Switch) -> bool
Checks if a switch is mapped to a channel
Sourcepub fn get_rc_struct(&self) -> &RcStruct
pub fn get_rc_struct(&self) -> &RcStruct
Gets a reference to the raw, unprocessed RC data
Sourcepub fn read_raw_chan(&self, chan_idx: usize) -> f32
pub fn read_raw_chan(&self, chan_idx: usize) -> f32
Reads a raw, normalized (0.0 to 1.0) channel value